package store

import (
	"fmt"
	"gitea.deepak.science/deepak/gogmagog/models"
)

func (e *errorStore) SelectActions() ([]*models.Action, error) {
	return nil, e.error
}

func (e *errorStore) SelectActionByID(id int) (*models.Action, error) {
	return nil, e.error
}

func (e *errorStore) InsertAction(action *models.Action) (int, error) {
	if e.errorOnInsert {
		return 0, e.error
	}
	return 0, nil
}

func (e *errorStore) UpdateAction(action *models.Action) error {
	if e.errorOnInsert {
		return e.error
	}
	return nil
}

func (e *errorStore) SelectPlans() ([]*models.Plan, error) {
	return nil, e.error
}

func (e *errorStore) SelectPlanByID(id int) (*models.Plan, error) {
	return nil, e.error
}

func (e *errorStore) InsertPlan(plan *models.Plan) (int, error) {
	if e.errorOnInsert {
		return 0, e.error
	}
	return 0, nil
}

func (e *errorStore) SelectActionsByPlanID(plan *models.Plan) ([]*models.Action, error) {
	return nil, e.error
}

func (e *errorStore) SelectUserByUsername(name string) (*models.User, error) {
	return nil, e.error
}

func (e *errorStore) InsertUser(user *models.User) (int, error) {
	if e.errorOnInsert {
		return 0, e.error
	}
	return 0, nil
}

func (e *errorStore) ConnectionLive() error {
	return e.error
}

type errorStore struct {
	error         error
	errorOnInsert bool
}

// GetErrorStore returns a models.Store that always errors. This is useful for testirng purposes.
func GetErrorStore(errorMsg string, errorOnInsert bool) models.Store {
	e := &errorStore{error: fmt.Errorf(errorMsg), errorOnInsert: errorOnInsert}
	return e
}
