package store_test

import (
	"gitea.deepak.science/deepak/gogmagog/models"
	"gitea.deepak.science/deepak/gogmagog/store"
	"github.com/stretchr/testify/assert"
	"testing"
)

func TestErrorActionMethods(t *testing.T) {
	assert := assert.New(t)
	str := store.GetErrorStore("error message sample", true)
	str2 := store.GetErrorStore("error message sample", false)

	_, err := str.InsertAction(&models.Action{})
	assert.NotNil(err)
	_, err = str2.InsertAction(&models.Action{})
	assert.Nil(err)

	_, err = str.SelectActionByID(8)
	assert.NotNil(err)
	_, err = str2.SelectActionByID(8)
	assert.NotNil(err)

	_, err = str.SelectActions()
	assert.NotNil(err)

	_, err = str.SelectActionsByPlanID(&models.Plan{})
	assert.NotNil(err)

	replacementAction := &models.Action{}
	err = str.UpdateAction(replacementAction)
	assert.NotNil(err)
	err = str2.UpdateAction(replacementAction)
	assert.Nil(err)

}

func TestErrorPlanMethods(t *testing.T) {
	assert := assert.New(t)
	str := store.GetErrorStore("sntahoeu", true)
	str2 := store.GetErrorStore("sntahoeu", false)

	_, err := str.SelectPlans()
	assert.NotNil(err)

	_, err = str.InsertPlan(&models.Plan{})
	assert.NotNil(err)
	_, err = str2.InsertPlan(&models.Plan{})
	assert.Nil(err)

	_, err = str.SelectPlanByID(5)
	assert.NotNil(err)

}

func TestErrorLive(t *testing.T) {
	assert := assert.New(t)
	str := store.GetErrorStore("error", true)

	err := str.ConnectionLive()
	assert.NotNil(err)
}

func TestErrorUserMethods(t *testing.T) {
	assert := assert.New(t)
	str := store.GetErrorStore("error", true)
	str2 := store.GetErrorStore("error", false)

	u := &models.User{}

	_, err := str.InsertUser(u)
	assert.NotNil(err)
	_, err = str2.InsertUser(u)
	assert.Nil(err)

	_, err = str.SelectUserByUsername("snth")
	assert.NotNil(err)
}
